@@ -1,4 +1,16 @@
 {-# OPTIONS -fglasgow-exts #-}
+-----------------------------------------------------------------------------
+-- |
+-- Module      :  Platform
+-- Copyright   :  Malcolm Wallace
+-- 
+-- Maintainer  :  Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
+-- Stability   :  Stable
+-- Portability :  All
+--
+-- Platform specific definitions, utilizing cpp pragmas, etc.
+-----------------------------------------------------------------------------
+
 module Platform
   ( withDefault
   , builtby
@@ -8,9 +20,10 @@ module Platform
   , escape
   , unsafePerformIO
   , getProcessID
+  , shell
   ) where
 
-import System (getEnv)
+import System (getEnv,system)
 import List (isPrefixOf)
 
 #ifdef __HBC__
@@ -27,7 +40,7 @@ import NHC.Internal (unsafePerformIO)
 foreign import ccall "getpid" getProcessID :: IO Int
 #endif
 #ifdef __GLASGOW_HASKELL__
-import IOExts (unsafePerformIO)
+import System.IO.Unsafe (unsafePerformIO)
 foreign import ccall "getpid" getProcessID :: IO Int
 #endif
 
@@ -41,7 +54,10 @@ withDefault name def = unsafePerformIO $
 -- Some variables imported from the shell environment
 builtby = "BUILTBY" `withDefault` "unknown"
 machine = "MACHINE" `withDefault` "unknown"
+cygshel = "CYGSHELL" `withDefault` "/cygwin/bin/bash"
 windows = "ix86-CYGWIN" `isPrefixOf` machine
 exe prg = if windows then prg++".exe" else prg
 escape  = if windows then map (\c-> if c=='\\' then '/' else c) else id
 
+shell cmd = if windows then system (cygshel++" -cl \""++cmd++"\"")
+                       else system cmd
